@@ -36,20 +36,13 @@ expected_csvfile_meta = {
 
 
 def test_mswlocationset(loc_sets):
-    assert loc_sets.mswloc.fews_config.path == constants.WIS_CONFIG_TEST_DIR
-    assert loc_sets.mswloc.idmap_section_name == expected_idmap_section_name
-    assert loc_sets.mswloc.name == expected_name
-    assert loc_sets.mswloc.csv_filename == expected_csvfile
-    assert loc_sets.mswloc.fews_name == expected_fews_name
-    assert (
-        loc_sets.mswloc.get_validation_attributes(int_pars=None)
-        == expected_validation_attributes
-    )
-    assert loc_sets.mswloc.validation_rules == expected_validation_rules
-    assert loc_sets.mswloc.csv_file_meta == expected_csvfile_meta
-    assert loc_sets.mswloc.attrib_files == expected_attrib_files
-    assert isinstance(loc_sets.mswloc.geo_df, pd.DataFrame)
-    assert isinstance(loc_sets.mswloc.geo_df_original, pd.DataFrame)
-    pd.testing.assert_frame_equal(
-        left=loc_sets.mswloc.geo_df, right=loc_sets.mswloc.geo_df_original
-    )
+    assert loc_sets.msw_loc.fews_config.path == constants.TEST_DIR_WIS_CONFIG
+    assert loc_sets.msw_loc.idmap_section_name == expected_idmap_section_name
+    assert loc_sets.msw_loc.name == expected_name
+    assert loc_sets.msw_loc.csv_filename == expected_csvfile
+    assert loc_sets.msw_loc.fews_name == expected_fews_name
+    assert loc_sets.msw_loc.get_validation_attributes(int_pars=None) == expected_validation_attributes
+    assert loc_sets.msw_loc.validation_rules == expected_validation_rules
+    assert loc_sets.msw_loc.csv_file_meta == expected_csvfile_meta
+    assert loc_sets.msw_loc.attrib_files == expected_attrib_files
+    assert isinstance(loc_sets.msw_loc.geo_df, pd.DataFrame)
