@@ -53,40 +53,17 @@ expected_validation_rules_1_and_2 = [
     {"parameter": "Hh.", "extreme_values": {"hmax": "HEF_HMAX", "hmin": "HEF_HMIN"}},
     {
         "parameter": "POS.",
-        "extreme_values": {
-            "hmax": "PERC_HMAX",
-            "smax": "PERC_SMAX",
-            "smin": "PERC_SMIN",
-            "hmin": "PERC_HMIN",
-        },
+        "extreme_values": {"hmax": "PERC_HMAX", "smax": "PERC_SMAX", "smin": "PERC_SMIN", "hmin": "PERC_HMIN",},
     },
     {
         "parameter": "POS2.",
-        "extreme_values": {
-            "hmax": "PERC2_HMAX",
-            "smax": "PERC2_SMAX",
-            "smin": "PERC2_SMIN",
-            "hmin": "PERC2_HMIN",
-        },
+        "extreme_values": {"hmax": "PERC2_HMAX", "smax": "PERC2_SMAX", "smin": "PERC2_SMIN", "hmin": "PERC2_HMIN",},
     },
     {"parameter": "TT.", "extreme_values": {"hmax": "TT_HMAX", "hmin": "TT_HMIN"}},
-    {
-        "parameter": "Q.G.",
-        "extreme_values": {
-            "hmax": "Q_HMAX",
-            "smax": "Q_SMAX",
-            "smin": "Q_SMIN",
-            "hmin": "Q_HMIN",
-        },
-    },
+    {"parameter": "Q.G.", "extreme_values": {"hmax": "Q_HMAX", "smax": "Q_SMAX", "smin": "Q_SMIN", "hmin": "Q_HMIN",},},
     {
         "parameter": "H.G.",
-        "extreme_values": {
-            "hmax": "H_HMAX",
-            "smax": "HW_SMAX",
-            "smin": "HW_SMIN",
-            "hmin": "H_HMIN",
-        },
+        "extreme_values": {"hmax": "H_HMAX", "smax": "HW_SMAX", "smin": "HW_SMIN", "hmin": "H_HMIN",},
     },
 ]
 
@@ -130,11 +107,7 @@ expected_csvfile_meta_1_and_2 = {
         {"text": "%HBEN%", "id": "HBEN"},
         {"text": "%AFGB_NAAR%", "id": "AFGB_NAAR"},
         {"text": "%AFGB_VAN%", "id": "AFGB_VAN"},
-        {
-            "description": "Dit attribuut wordt in de filters gebruikt",
-            "boolean": "%SWM%",
-            "id": "SWM",
-        },
+        {"description": "Dit attribuut wordt in de filters gebruikt", "boolean": "%SWM%", "id": "SWM",},
         {"boolean": "%NWW-MDV%", "id": "SWMGEBIED_NWW-MDV"},
     ],
     "attributeFile": [
@@ -291,30 +264,21 @@ expected_csvfile_meta_1_and_2 = {
             "id": "%LOC_ID%",
             "startDateTime": "%STARTDATE%",
             "endDateTime": "%ENDDATE%",
-            "attribute": [
-                {"number": "%HR1_HMAX%", "id": "HR1_HMAX"},
-                {"number": "%HR1_HMIN%", "id": "HR1_HMIN"},
-            ],
+            "attribute": [{"number": "%HR1_HMAX%", "id": "HR1_HMAX"}, {"number": "%HR1_HMIN%", "id": "HR1_HMIN"},],
         },
         {
             "csvFile": "oppvlwater_kunstvalidatie_stuur2.csv",
             "id": "%LOC_ID%",
             "startDateTime": "%STARTDATE%",
             "endDateTime": "%ENDDATE%",
-            "attribute": [
-                {"number": "%HR2_HMAX%", "id": "HR2_HMAX"},
-                {"number": "%HR2_HMIN%", "id": "HR2_HMIN"},
-            ],
+            "attribute": [{"number": "%HR2_HMAX%", "id": "HR2_HMAX"}, {"number": "%HR2_HMIN%", "id": "HR2_HMIN"},],
         },
         {
             "csvFile": "oppvlwater_kunstvalidatie_stuur3.csv",
             "id": "%LOC_ID%",
             "startDateTime": "%STARTDATE%",
             "endDateTime": "%ENDDATE%",
-            "attribute": [
-                {"number": "%HR3_HMAX%", "id": "HR3_HMAX"},
-                {"number": "%HR3_HMIN%", "id": "HR3_HMIN"},
-            ],
+            "attribute": [{"number": "%HR3_HMAX%", "id": "HR3_HMAX"}, {"number": "%HR3_HMIN%", "id": "HR3_HMIN"},],
         },
         {
             "csvFile": "herberekeningDebietenLocsets.csv",
@@ -323,10 +287,7 @@ expected_csvfile_meta_1_and_2 = {
                 {"relatedLocationId": "%totaal_plus%", "id": "totaal_plus"},
                 {"relatedLocationId": "%totaal_min%", "id": "totaal_min"},
             ],
-            "attribute": [
-                {"text": "%formule%", "id": "formule"},
-                {"text": "%keuze_formule%", "id": "keuze_formule"},
-            ],
+            "attribute": [{"text": "%formule%", "id": "formule"}, {"text": "%keuze_formule%", "id": "keuze_formule"},],
         },
         {
             "csvFile": "herberekeningDebieten.csv",
@@ -524,30 +485,21 @@ expected_attrib_files_1_and_2 = [
         "id": "%LOC_ID%",
         "startDateTime": "%STARTDATE%",
         "endDateTime": "%ENDDATE%",
-        "attribute": [
-            {"number": "%HR1_HMAX%", "id": "HR1_HMAX"},
-            {"number": "%HR1_HMIN%", "id": "HR1_HMIN"},
-        ],
+        "attribute": [{"number": "%HR1_HMAX%", "id": "HR1_HMAX"}, {"number": "%HR1_HMIN%", "id": "HR1_HMIN"},],
     },
     {
         "csvFile": "oppvlwater_kunstvalidatie_stuur2.csv",
         "id": "%LOC_ID%",
         "startDateTime": "%STARTDATE%",
         "endDateTime": "%ENDDATE%",
-        "attribute": [
-            {"number": "%HR2_HMAX%", "id": "HR2_HMAX"},
-            {"number": "%HR2_HMIN%", "id": "HR2_HMIN"},
-        ],
+        "attribute": [{"number": "%HR2_HMAX%", "id": "HR2_HMAX"}, {"number": "%HR2_HMIN%", "id": "HR2_HMIN"},],
     },
     {
         "csvFile": "oppvlwater_kunstvalidatie_stuur3.csv",
         "id": "%LOC_ID%",
         "startDateTime": "%STARTDATE%",
         "endDateTime": "%ENDDATE%",
-        "attribute": [
-            {"number": "%HR3_HMAX%", "id": "HR3_HMAX"},
-            {"number": "%HR3_HMIN%", "id": "HR3_HMIN"},
-        ],
+        "attribute": [{"number": "%HR3_HMAX%", "id": "HR3_HMAX"}, {"number": "%HR3_HMIN%", "id": "HR3_HMIN"},],
     },
     {
         "csvFile": "herberekeningDebietenLocsets.csv",
@@ -556,10 +508,7 @@ expected_attrib_files_1_and_2 = [
             {"relatedLocationId": "%totaal_plus%", "id": "totaal_plus"},
             {"relatedLocationId": "%totaal_min%", "id": "totaal_min"},
         ],
-        "attribute": [
-            {"text": "%formule%", "id": "formule"},
-            {"text": "%keuze_formule%", "id": "keuze_formule"},
-        ],
+        "attribute": [{"text": "%formule%", "id": "formule"}, {"text": "%keuze_formule%", "id": "keuze_formule"},],
     },
     {
         "csvFile": "herberekeningDebieten.csv",
@@ -595,29 +544,19 @@ expected_attrib_files_1_and_2 = [
     {
         "csvFile": "herberekeningDebieten_h.csv",
         "id": "%locid%",
-        "attribute": [
-            {"number": "%bovenpeil%", "id": "bovenpeil"},
-            {"number": "%benedenpeil%", "id": "benedenpeil"},
-        ],
+        "attribute": [{"number": "%bovenpeil%", "id": "bovenpeil"}, {"number": "%benedenpeil%", "id": "benedenpeil"},],
     },
 ]
 
 
 def test_sublocationset(loc_sets):
-    assert loc_sets.subloc.fews_config.path == constants.WIS_CONFIG_TEST_DIR
-    assert loc_sets.subloc.idmap_section_name == expected_idmap_section_name
-    assert loc_sets.subloc.name == expected_name
-    assert loc_sets.subloc.csv_filename == expected_csvfile
-    assert loc_sets.subloc.fews_name == expected_fews_name
-    assert (
-        loc_sets.subloc.get_validation_attributes(int_pars=None)
-        == expected_validation_attributes
-    )
-    assert loc_sets.subloc.validation_rules == expected_validation_rules_1_and_2
-    assert loc_sets.subloc.csv_file_meta == expected_csvfile_meta_1_and_2
-    assert loc_sets.subloc.attrib_files == expected_attrib_files_1_and_2
-    assert isinstance(loc_sets.subloc.geo_df, pd.DataFrame)
-    assert isinstance(loc_sets.subloc.geo_df_original, pd.DataFrame)
-    pd.testing.assert_frame_equal(
-        left=loc_sets.subloc.geo_df, right=loc_sets.subloc.geo_df_original
-    )
+    assert loc_sets.sub_loc.fews_config.path == constants.TEST_DIR_WIS_CONFIG
+    assert loc_sets.sub_loc.idmap_section_name == expected_idmap_section_name
+    assert loc_sets.sub_loc.name == expected_name
+    assert loc_sets.sub_loc.csv_filename == expected_csvfile
+    assert loc_sets.sub_loc.fews_name == expected_fews_name
+    assert loc_sets.sub_loc.get_validation_attributes(int_pars=None) == expected_validation_attributes
+    assert loc_sets.sub_loc.validation_rules == expected_validation_rules_1_and_2
+    assert loc_sets.sub_loc.csv_file_meta == expected_csvfile_meta_1_and_2
+    assert loc_sets.sub_loc.attrib_files == expected_attrib_files_1_and_2
+    assert isinstance(loc_sets.sub_loc.geo_df, pd.DataFrame)
