@@ -36,9 +36,7 @@ class ValidationCsvChoices(Enum):
             if bool(re.match(pattern=int_par_regex, string=int_par))
         ]
         if not match:
-            logger.debug(
-                f"no validation csv found: int_par={int_par} not in INTPAR_2_VALIDATION_CSV.keys"
-            )
+            logger.debug(f"no validation csv found: int_par={int_par} not in INTPAR_2_VALIDATION_CSV.keys")
             return ""
         assert len(match) == 1
         mapper = INTPAR_2_VALIDATION_CSV[match[0]]
@@ -63,37 +61,15 @@ INTPAR_2_VALIDATION_CSV = {
         # we only validate it for debietmeters (not schuif, vispassage, pompvijzel, stuw)
         SubLocTypeChoices.debietmeter.value: ValidationCsvChoices.ow_validatie_debiet.value
     },
-    "F.": {
-        SubLocTypeChoices.pompvijzel.value: ValidationCsvChoices.ow_validatie_freq.value
-    },
-    "Hk.": {
-        SubLocTypeChoices.stuw.value: ValidationCsvChoices.ow_validatie_kruinh.value
-    },
-    "POS.": {
-        SubLocTypeChoices.schuif.value: ValidationCsvChoices.ow_validatie_schuifp.value
-    },
-    "POS2.": {
-        SubLocTypeChoices.schuif.value: ValidationCsvChoices.ow_validatie_schuifp2.value
-    },
-    "H.S.": {
-        HoofdLocTypeChoices.waterstand.value: ValidationCsvChoices.ow_validatie_streef1.value
-    },
-    "H2.S.": {
-        HoofdLocTypeChoices.waterstand.value: ValidationCsvChoices.ow_validatie_streef2.value
-    },
-    "H3.S.": {
-        HoofdLocTypeChoices.waterstand.value: ValidationCsvChoices.ow_validatie_streef3.value
-    },
-    "H.R.": {
-        HoofdLocTypeChoices.waterstand.value: ValidationCsvChoices.ow_validatie_stuur1.value
-    },
-    "H2.R.": {
-        HoofdLocTypeChoices.waterstand.value: ValidationCsvChoices.ow_validatie_stuur2.value
-    },
-    "H3.R.": {
-        HoofdLocTypeChoices.waterstand.value: ValidationCsvChoices.ow_validatie_stuur3.value
-    },
-    "TT.": {
-        SubLocTypeChoices.pompvijzel.value: ValidationCsvChoices.ow_validatie_toert.value
-    },
+    "F.": {SubLocTypeChoices.pompvijzel.value: ValidationCsvChoices.ow_validatie_freq.value},
+    "Hk.": {SubLocTypeChoices.stuw.value: ValidationCsvChoices.ow_validatie_kruinh.value},
+    "POS.": {SubLocTypeChoices.schuif.value: ValidationCsvChoices.ow_validatie_schuifp.value},
+    "POS2.": {SubLocTypeChoices.schuif.value: ValidationCsvChoices.ow_validatie_schuifp2.value},
+    "H.S.": {HoofdLocTypeChoices.waterstand.value: ValidationCsvChoices.ow_validatie_streef1.value},
+    "H2.S.": {HoofdLocTypeChoices.waterstand.value: ValidationCsvChoices.ow_validatie_streef2.value},
+    "H3.S.": {HoofdLocTypeChoices.waterstand.value: ValidationCsvChoices.ow_validatie_streef3.value},
+    "H.R.": {HoofdLocTypeChoices.waterstand.value: ValidationCsvChoices.ow_validatie_stuur1.value},
+    "H2.R.": {HoofdLocTypeChoices.waterstand.value: ValidationCsvChoices.ow_validatie_stuur2.value},
+    "H3.R.": {HoofdLocTypeChoices.waterstand.value: ValidationCsvChoices.ow_validatie_stuur3.value},
+    "TT.": {SubLocTypeChoices.pompvijzel.value: ValidationCsvChoices.ow_validatie_toert.value},
 }
